X-Git-Url: http://git.ithinksw.org/extjs.git/blobdiff_plain/25ef3491bd9ae007ff1fc2b0d7943e6eaaccf775..6b044c28b5f26fb99c86c237ffad19741c0f7f3d:/src/widgets/chart/FlashComponent.js?ds=inline
diff --git a/src/widgets/chart/FlashComponent.js b/src/widgets/chart/FlashComponent.js
index e11fd770..1398c310 100644
--- a/src/widgets/chart/FlashComponent.js
+++ b/src/widgets/chart/FlashComponent.js
@@ -1,8 +1,8 @@
/*!
- * Ext JS Library 3.0.3
- * Copyright(c) 2006-2009 Ext JS, LLC
- * licensing@extjs.com
- * http://www.extjs.com/license
+ * Ext JS Library 3.3.1
+ * Copyright(c) 2006-2010 Sencha Inc.
+ * licensing@sencha.com
+ * http://www.sencha.com/license
*/
/**
* @class Ext.FlashComponent
@@ -13,9 +13,9 @@
Ext.FlashComponent = Ext.extend(Ext.BoxComponent, {
/**
* @cfg {String} flashVersion
* Indicates the version the flash content was published for. Defaults to '9.0.45'.
*/
- flashVersion : '9.0.45',
+ flashVersion : '9.0.115',
/**
* @cfg {String} backgroundColor
@@ -28,13 +28,13 @@ Ext.FlashComponent = Ext.extend(Ext.BoxComponent, {
* The wmode of the flash object. This can be used to control layering. Defaults to 'opaque'.
*/
wmode: 'opaque',
-
+
/**
* @cfg {Object} flashVars
* A set of key value pairs to be passed to the flash object as flash variables. Defaults to undefined.
*/
flashVars: undefined,
-
+
/**
* @cfg {Object} flashParams
* A set of key value pairs to be passed to the flash object as parameters. Possible parameters can be found here:
@@ -61,7 +61,14 @@ Ext.FlashComponent = Ext.extend(Ext.BoxComponent, {
initComponent : function(){
Ext.FlashComponent.superclass.initComponent.call(this);
- this.addEvents('initialize');
+ this.addEvents(
+ /**
+ * @event initialize
+ *
+ * @param {Chart} this
+ */
+ 'initialize'
+ );
},
onRender : function(){
@@ -73,8 +80,8 @@ Ext.FlashComponent = Ext.extend(Ext.BoxComponent, {
wmode: this.wmode
}, this.flashParams), vars = Ext.apply({
allowedDomain: document.location.hostname,
- elementID: this.getId(),
- eventHandler: 'Ext.FlashEventProxy.onEvent'
+ YUISwfId: this.getId(),
+ YUIBridgeCallback: 'Ext.FlashEventProxy.onEvent'
}, this.flashVars);
new swfobject.embedSWF(this.url, this.id, this.swfWidth, this.swfHeight, this.flashVersion,
@@ -13,9 +13,9 @@
/**
* @cfg {String} flashVersion
- * Indicates the version the flash content was published for. Defaults to '9.0.45'.
+ * Indicates the version the flash content was published for. Defaults to '9.0.115'.
*/